<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="hr" sourcelanguage="">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Behavior</source>
        <translation>Ponašanje</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Automatically save documents</source>
        <translation>Automatsko spremanje dokumenata</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Automatically open last documents on startup</source>
        <translation>Otvaranje zadnje uređivanoga dokumenta prilikom pokretanja</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Restore window geometry</source>
        <translation>Pamćenje dimenzije prozora</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Open external links in ReText window</source>
        <translation>Otvaraj vanjske poveznice u ReTextu</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Markdown syntax extensions (comma-separated)</source>
        <translation>Proširenje sintakse Markdowna (odvajati zarezom)</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Enable synchronized scrolling for Markdown</source>
        <translation>Koristi sinkroniziran klizač za Markdown</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="169"/>
        <source>Editor</source>
        <translation>Uređivač</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Highlight current line</source>
        <translation>Istakni aktivni redak</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Show line numbers</source>
        <translation>Prikaži brojeve redaka</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Tab key inserts spaces</source>
        <translation>Tab umeće bjeline</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Tabulation width</source>
        <translation>Širina tabulatora</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Draw vertical line at column</source>
        <translation>Prikaži okomitu liniju na stupcu</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Interface</source>
        <translation>Sučelje</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Icon theme name</source>
        <translation>Naziv teme ikona</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Stylesheet file</source>
        <translation>Datoteka lista stilova</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Show document stats</source>
        <translation>Prikaz statističkih podataka dokumenta</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="151"/>
        <source>Help</source>
        <translation>Pomoć</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="80"/>
        <source>Using configuration file at:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Number of recent documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Default preview state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Line numbers are relative to current line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Enable soft wrap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Hide toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Hide tabs bar when there is only one tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Show full path in window title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="170"/>
        <source>Live preview</source>
        <translation type="unfinished">Pregled uživo</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="171"/>
        <source>Normal preview</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileSelectButton</name>
    <message>
        <location filename="../ReText/config.py" line="35"/>
        <source>(none)</source>
        <translation>(ništa)</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="42"/>
        <source>Select file to open</source>
        <translation>Odaberite datoteku za otvaranje</translation>
    </message>
</context>
<context>
    <name>InsertTableDialog</name>
    <message>
        <location filename="../ReText/tabledialog.py" line="27"/>
        <source>Insert table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/tabledialog.py" line="36"/>
        <source>Number of rows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/tabledialog.py" line="37"/>
        <source>Number of columns</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../ReText/dialogs.py" line="44"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>Unesite naziv lokalizacijske datoteke (npr. hr)</translation>
    </message>
    <message>
        <location filename="../ReText/dialogs.py" line="50"/>
        <source>Set as default</source>
        <translation>Postavi kao zadano</translation>
    </message>
</context>
<context>
    <name>Proxy</name>
    <message>
        <location filename="../ReText/fakevimeditor.py" line="61"/>
        <source>No write since last change (add ! to override)</source>
        <translation>Nema unosa od zadnje izmjene (dodajte ! da pregazite)</translation>
    </message>
    <message>
        <location filename="../ReText/fakevimeditor.py" line="118"/>
        <source>Information</source>
        <translation>Informacije</translation>
    </message>
</context>
<context>
    <name>ReTextEdit</name>
    <message>
        <location filename="../ReText/editor.py" line="391"/>
        <source>Save image</source>
        <translation>Spremi sliku</translation>
    </message>
    <message>
        <location filename="../ReText/editor.py" line="391"/>
        <source>Images (*.png *.jpg)</source>
        <translation>Slike (*.png *.jpg)</translation>
    </message>
    <message>
        <location filename="../ReText/editor.py" line="212"/>
        <source>Add to dictionary</source>
        <translation>Dodaj riječ u rječnik</translation>
    </message>
</context>
<context>
    <name>ReTextTab</name>
    <message>
        <location filename="../ReText/tab.py" line="184"/>
        <source>New document</source>
        <translation>Novi dokument</translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="189"/>
        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
        <translation>Nije moguće raščlaniti sadržaj datoteke. Provjerite imate li instaliran &lt;a href=&quot;%s&quot;&gt;potreban modul&lt;/a&gt;!</translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="478"/>
        <source>Create missing file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="478"/>
        <source>The file &apos;%s&apos; does not exist.

Do you want to create it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="511"/>
        <source>File could not be created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="511"/>
        <source>Could not create file &apos;%s&apos;: %s</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="../ReText/window.py" line="82"/>
        <source>File toolbar</source>
        <translation>Alatna traka datoteka</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="84"/>
        <source>Edit toolbar</source>
        <translation>Alatna traka uređivanja</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="86"/>
        <source>Search toolbar</source>
        <translation>Alatna traka traženja</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="90"/>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="93"/>
        <source>Open</source>
        <translation>Otvori</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="96"/>
        <source>Set encoding</source>
        <translation>Postavi kodiranje</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1190"/>
        <source>Reload</source>
        <translation>Ponovno učitaj</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="102"/>
        <source>Save</source>
        <translation>Spremi</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="106"/>
        <source>Save as</source>
        <translation>Spremi kao</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="108"/>
        <source>Next tab</source>
        <translation>Sljedeća kartica</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="110"/>
        <source>Previous tab</source>
        <translation>Prethodna kartica</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="112"/>
        <source>Close tab</source>
        <translation>Zatvori karticu</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="114"/>
        <source>Print</source>
        <translation>Ispis</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="117"/>
        <source>Print preview</source>
        <translation>Prikaz ispisa</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="119"/>
        <source>View HTML code</source>
        <translation>Pregled HTML koda</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="120"/>
        <source>Change editor font</source>
        <translation>Promjena fonta uređivača</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="122"/>
        <source>Change preview font</source>
        <translation>Promjena fonta pregleda</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="124"/>
        <source>Find text</source>
        <translation>Traži u tekstu</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="129"/>
        <source>Preview</source>
        <translation>Pregled</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="139"/>
        <source>Live preview</source>
        <translation>Pregled uživo</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="146"/>
        <source>Table editing mode</source>
        <translation>Uređivanje tablica kao način rada</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="152"/>
        <source>FakeVim mode</source>
        <translation>Lažni Vim kao način rada</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="157"/>
        <source>Fullscreen mode</source>
        <translation>Prikaz preko cijeloga zaslona kao način rada</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="630"/>
        <source>Preferences</source>
        <translation>Podešavanja</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="168"/>
        <source>Quit</source>
        <translation>Zatvori</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="171"/>
        <source>Undo</source>
        <translation>Vrati prethodno</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="173"/>
        <source>Redo</source>
        <translation>Ponovi prethodno</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="175"/>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="177"/>
        <source>Cut</source>
        <translation>Izreži</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="179"/>
        <source>Paste</source>
        <translation>Umetni</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="195"/>
        <source>Enable</source>
        <translation>Omogući</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="196"/>
        <source>Set locale</source>
        <translation>Postavljanje jezika</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="197"/>
        <source>Use WebKit renderer</source>
        <translation>Koristi WebKit crtač</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="202"/>
        <source>Use WebEngine (Chromium) renderer</source>
        <translation>Koristi WebEngine (Chromium) crtač</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="207"/>
        <source>Show directory</source>
        <translation>Prikaži sadržaj mape</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="208"/>
        <source>Next</source>
        <translation>Sljedeće</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="210"/>
        <source>Previous</source>
        <translation>Prethodno</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="212"/>
        <source>Replace</source>
        <translation>Zamijeni</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="214"/>
        <source>Replace all</source>
        <translation>Zamijeni sve</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="218"/>
        <source>Close</source>
        <translation>Zatvori</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="222"/>
        <source>Get help online</source>
        <translation>Traženje pomoći na internetu</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="223"/>
        <source>About ReText</source>
        <translation>O ReTextu</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="226"/>
        <source>About Qt</source>
        <translation>O Qt-u</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="241"/>
        <source>Bold</source>
        <translation>Podebljano</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="243"/>
        <source>Italic</source>
        <translation>Ukošeno</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="245"/>
        <source>Underline</source>
        <translation>Podvučeno</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="318"/>
        <source>Formatting</source>
        <translation>Oblikovanje</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="258"/>
        <source>Symbols</source>
        <translation>Simboli</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="263"/>
        <source>File</source>
        <translation>Datoteka</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="264"/>
        <source>Edit</source>
        <translation>Uređivanje</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="265"/>
        <source>Help</source>
        <translation>Pomoć</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="268"/>
        <source>Open recent</source>
        <translation>Otvori nedavno uređivane dokumente</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="281"/>
        <source>Export</source>
        <translation>Izvoz</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="306"/>
        <source>Spell check</source>
        <translation>Provjera pravopisa</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="315"/>
        <source>Default markup</source>
        <translation>Zadana sintaksa</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="360"/>
        <source>Search</source>
        <translation>Traži</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="363"/>
        <source>Replace with</source>
        <translation>Zamijeni s</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="365"/>
        <source>Case sensitively</source>
        <translation>Razlikuj velika i mala slova</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="526"/>
        <source>New document</source>
        <translation>Novi dokument</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="714"/>
        <source>Please, save the file somewhere.</source>
        <translation>Spremite datoteku.</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="830"/>
        <source>Select one or several files to open</source>
        <translation>Odaberite jednu ili više datoteka za otvaranje</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1248"/>
        <source>Supported files</source>
        <translation>Podržani tipovi datoteka</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1248"/>
        <source>All files (*)</source>
        <translation>Sve tipovi datoteka (*)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="869"/>
        <source>Select file encoding from the list:</source>
        <translation>Odaberite vrstu kodiranja znakova u datoteci:</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="892"/>
        <source>Plain text (*.txt)</source>
        <translation>Običan tekst (*.txt)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="895"/>
        <source>%s files</source>
        <comment>Example of final string: Markdown files</comment>
        <translation>%s datoteke</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="970"/>
        <source>Save file</source>
        <translation>Spremi datoteku</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="915"/>
        <source>Cannot save to file which is open in another tab!</source>
        <translation>Datoteku nije moguće spremiti jer je otvorena u drugoj kartici.</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="938"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Datoteku nije moguće spremiti jer je dozvoljeno samo njezino čitanje.</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="960"/>
        <source>Export document to ODT</source>
        <translation>Izvezi datoteku kao ODT</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="960"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>OpenDocument tekstna datoteka (*.odt)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="970"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>HTML datoteka (*.html *.htm)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1019"/>
        <source>Export document to PDF</source>
        <translation>Izvezi datoteku kao PDF</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1019"/>
        <source>PDF files (*.pdf)</source>
        <translation>PDF datoteke (*.pdf)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1046"/>
        <source>Print document</source>
        <translation>Ispis dokumenta</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1069"/>
        <source>Export document</source>
        <translation>Izvezi dokument</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1090"/>
        <source>Failed to execute the command:</source>
        <translation>Naredba nije izvršena:</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1131"/>
        <source>Alt text</source>
        <translation>Tekst kao alternativa</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1132"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1132"/>
        <source>Link text</source>
        <translation>Poveznica na tekst</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1173"/>
        <source>This file has been deleted by other application.
Please make sure you save the file before exit.</source>
        <translation>Datoteku izbrisala neka druga aplikacija.
Spremite datoteku prije zatvaranja.</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1181"/>
        <source>This document has been modified by other application.
Do you want to reload the file (this will discard all your changes)?
</source>
        <translation>Datoteka je izmijenjena i nekom drugom aplikacijom.
Želite li je ponovno učitati? Ovo će poništiti vaše izmjene.</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1186"/>
        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
        <translation>Ako ne učitate ponovno datoteku, automatsko će spremanje biti onemogućeno za ovu sesiju kako bi se spriječio gubitak podataka.</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1210"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Dokument je izmijenjen.
Želite li spremiti izmjene?</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1238"/>
        <source>HTML code</source>
        <translation>HTML kod</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>ReText %s (using PyMarkups %s)</source>
        <translation>ReText %s (koristeći PyMarkups %s)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>Simple but powerful editor for Markdown and reStructuredText</source>
        <translation>Jednostavan ali moćan uređivač Markdowna i reStructuredTexta</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Autor: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>Website</source>
        <translation>Internetska stranica</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>Markdown syntax</source>
        <translation>Sintaksa Markdowna</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>reStructuredText syntax</source>
        <translation>Sintaksa reStructuredTexta</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="678"/>
        <source>Go to line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="144"/>
        <source>Insert table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="149"/>
        <source>Insert images by file path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="181"/>
        <source>Paste image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="183"/>
        <source>Move line up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="185"/>
        <source>Move line down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="678"/>
        <source>Type the line number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="993"/>
        <source>Unrecognized paperSize setting &quot;%s&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1248"/>
        <source>Select one or several images to open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextInfoArea</name>
    <message>
        <location filename="../ReText/editor.py" line="582"/>
        <source>%d w | %d a | %d c</source>
        <comment>count of words, alphanumeric characters, all characters</comment>
        <translation type="unfinished">%d m | %d a | %d c</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../ReText/__main__.py" line="77"/>
        <source>Open the files in preview mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/__main__.py" line="79"/>
        <source>Create a new window even if there is an existing one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/__main__.py" line="83"/>
        <source>List of files to open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
